@@ -99,6 +99,61 @@ hid_return hid_dump_tree(FILE* const out, HIDInterface* const hidif)
   return HID_RET_SUCCESS;
 }
 
+const char *hid_strerror(hid_return ret)
+{
+  switch(ret) {
+    case HID_RET_SUCCESS:
+      return "libhid: success";
+    case HID_RET_INVALID_PARAMETER:
+      return "libhid: invalid parameter";
+    case HID_RET_NOT_INITIALISED:
+      return "libhid: not initialized; call hid_init() first";
+    case HID_RET_ALREADY_INITIALISED:
+      return "libhid: hid_init() already called";
+    case HID_RET_FAIL_FIND_BUSSES:
+      return "libhid: failed to find any USB busses";
+    case HID_RET_FAIL_FIND_DEVICES:
+      return "libhid: failed to find any USB devices";
+    case HID_RET_FAIL_OPEN_DEVICE:
+      return "libhid: failed to open device";
+    case HID_RET_DEVICE_NOT_FOUND:
+      return "libhid: device not found";
+    case HID_RET_DEVICE_NOT_OPENED:
+      return "libhid: device not yet opened";
+    case HID_RET_DEVICE_ALREADY_OPENED:
+      return "libhid: device already opened";
+    case HID_RET_FAIL_CLOSE_DEVICE:
+      return "libhid: could not close device";
+    case HID_RET_FAIL_CLAIM_IFACE:
+      return "libhid: failed to claim interface; is another driver using it?";
+    case HID_RET_FAIL_DETACH_DRIVER:
+      return "libhid: failed to detach kernel driver";
+    case HID_RET_NOT_HID_DEVICE:
+      return "libhid: not recognized as a HID device";
+    case HID_RET_HID_DESC_SHORT:
+      return "libhid: HID interface descriptor too short";
+    case HID_RET_REPORT_DESC_SHORT:
+      return "libhid: HID report descriptor too short";
+    case HID_RET_REPORT_DESC_LONG:
+      return "libhid: HID report descriptor too long";
+    case HID_RET_FAIL_ALLOC:
+      return "libhid: failed to allocate memory";
+    case HID_RET_OUT_OF_SPACE:
+      return "libhid: no space left in buffer";
+    case HID_RET_FAIL_SET_REPORT:
+      return "libhid: failed to set report";
+    case HID_RET_FAIL_GET_REPORT:
+      return "libhid: failed to get report";
+    case HID_RET_FAIL_INT_READ:
+      return "libhid: interrupt read failed";
+    case HID_RET_NOT_FOUND:
+      return "libhid: not found";
+    case HID_RET_TIMEOUT:
+      return "libhid: timeout";
+  }
+  return "libhid: unknown error";
+}
+
 /* COPYRIGHT --
  *
  * This file is part of libhid, a user-space HID access library.
